@@ -8,7 +8,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-07-28'; # DATE
 our $DIST = 'Module-Installed-Tiny'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our @EXPORT_OK = qw(module_installed module_source);
 
@@ -161,7 +161,7 @@ Module::Installed::Tiny - Check if a module is installed, with as little code as
 
 =head1 VERSION
 
-This document describes version 0.007 of Module::Installed::Tiny (from Perl distribution Module-Installed-Tiny), released on 2022-07-28.
+This document describes version 0.008 of Module::Installed::Tiny (from Perl distribution Module-Installed-Tiny), released on 2022-07-28.
 
 =head1 SYNOPSIS
 
@@ -221,7 +221,7 @@ file cannot be read) with the same/similar message as Perl's C<require()>:
  Can't locate Foo/Bar.pm (you may need to install the Foo::Bar module) ...
 
 Module C<$name> can be in the form of C<Foo::Bar>, C<Foo/Bar.pm> or
-F<Foo\Bar.pm> (on Windows).
+C<Foo\Bar.pm> (on Windows).
 
 In list context:
 
@@ -256,7 +256,7 @@ in scalar context, or:
 in list context. In scalar context, you can differentiate path from module
 source because the path is returned as a scalar reference. So to get the path:
 
- $source_or_pathref = module_source("Foo/Bar.pm");
+ $source_or_pathref = module_source("Foo/Bar.pm", {find_prefix=>1});
  if (ref $source_or_pathref eq 'SCALAR') {
      say "Path is ", $$source_or_pathref;
  } else {
